catalog

package
v1.25.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 6, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Catalog

type Catalog struct {
	// contains filtered or unexported fields
}

func NewCatalog

func NewCatalog(conn *pgx.Conn, schemas []string) (*Catalog, error)

func (*Catalog) CompositeTypes added in v1.20.0

func (c *Catalog) CompositeTypes(ctx context.Context) (*orderedmap.Map[string, *model.CompositeType], error)

func (*Catalog) Domains added in v0.12.0

func (c *Catalog) Domains(ctx context.Context) (*orderedmap.Map[string, *model.Domain], error)

func (*Catalog) Enums added in v0.9.0

func (c *Catalog) Enums(ctx context.Context) (*orderedmap.Map[string, *model.Enum], error)

func (*Catalog) ListColumnsByTable

func (c *Catalog) ListColumnsByTable(ctx context.Context, table *model.Table) ([]*model.Column, error)

func (*Catalog) ListCompositeTypes added in v1.20.0

func (c *Catalog) ListCompositeTypes(ctx context.Context) ([]*model.CompositeType, error)

func (*Catalog) ListConstraintsByTable

func (c *Catalog) ListConstraintsByTable(ctx context.Context, table *model.Table) ([]*model.Constraint, []*model.ForeignKey, error)

func (*Catalog) ListDomains added in v0.12.0

func (c *Catalog) ListDomains(ctx context.Context) ([]*model.Domain, error)

func (*Catalog) ListEnums added in v0.9.0

func (c *Catalog) ListEnums(ctx context.Context) ([]*model.Enum, error)

func (*Catalog) ListIndexes

func (c *Catalog) ListIndexes(ctx context.Context) ([]*model.Index, error)

func (*Catalog) ListPoliciesByTable added in v1.3.0

func (c *Catalog) ListPoliciesByTable(ctx context.Context, table *model.Table) ([]*model.Policy, error)

ListPoliciesByTable returns row-level security policies attached to the given table, in pg_policy.polname order.

func (*Catalog) ListSequences added in v1.17.0

func (c *Catalog) ListSequences(ctx context.Context) ([]*model.Sequence, error)

ListSequences returns all sequences in the filtered schemas, including those owned by serial/identity columns. OwnerTable/OwnerColumn identify the owning column (nil for standalone sequences).

func (*Catalog) ListTables

func (c *Catalog) ListTables(ctx context.Context) ([]*model.Table, error)

func (*Catalog) ListViews

func (c *Catalog) ListViews(ctx context.Context) ([]*model.View, error)

func (*Catalog) Sequences

func (c *Catalog) Sequences(ctx context.Context) (*orderedmap.Map[string, *model.Sequence], error)

Sequences returns the standalone sequences in the filtered schemas, keyed by FQN. Sequences owned by a table column (serial or identity) are excluded: they are managed as column attributes, not as standalone objects.

func (*Catalog) Tables

func (c *Catalog) Tables(ctx context.Context) (*orderedmap.Map[string, *model.Table], error)

func (*Catalog) Views

func (c *Catalog) Views(ctx context.Context) (*orderedmap.Map[string, *model.View], error)

Jump to