Documentation
¶
Index ¶
- type Catalog
- func (c *Catalog) CompositeTypes(ctx context.Context) (*orderedmap.Map[string, *model.CompositeType], error)
- func (c *Catalog) Domains(ctx context.Context) (*orderedmap.Map[string, *model.Domain], error)
- func (c *Catalog) Enums(ctx context.Context) (*orderedmap.Map[string, *model.Enum], error)
- func (c *Catalog) ListColumnsByTable(ctx context.Context, table *model.Table) ([]*model.Column, error)
- func (c *Catalog) ListCompositeTypes(ctx context.Context) ([]*model.CompositeType, error)
- func (c *Catalog) ListConstraintsByTable(ctx context.Context, table *model.Table) ([]*model.Constraint, []*model.ForeignKey, error)
- func (c *Catalog) ListDomains(ctx context.Context) ([]*model.Domain, error)
- func (c *Catalog) ListEnums(ctx context.Context) ([]*model.Enum, error)
- func (c *Catalog) ListIndexes(ctx context.Context) ([]*model.Index, error)
- func (c *Catalog) ListPoliciesByTable(ctx context.Context, table *model.Table) ([]*model.Policy, error)
- func (c *Catalog) ListSequences(ctx context.Context) ([]*model.Sequence, error)
- func (c *Catalog) ListTables(ctx context.Context) ([]*model.Table, error)
- func (c *Catalog) ListViews(ctx context.Context) ([]*model.View, error)
- func (c *Catalog) Sequences(ctx context.Context) (*orderedmap.Map[string, *model.Sequence], error)
- func (c *Catalog) Tables(ctx context.Context) (*orderedmap.Map[string, *model.Table], error)
- func (c *Catalog) Views(ctx context.Context) (*orderedmap.Map[string, *model.View], error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Catalog ¶
type Catalog struct {
// contains filtered or unexported fields
}
func (*Catalog) CompositeTypes ¶ added in v1.20.0
func (c *Catalog) CompositeTypes(ctx context.Context) (*orderedmap.Map[string, *model.CompositeType], error)
func (*Catalog) ListColumnsByTable ¶
func (*Catalog) ListCompositeTypes ¶ added in v1.20.0
func (*Catalog) ListConstraintsByTable ¶
func (c *Catalog) ListConstraintsByTable(ctx context.Context, table *model.Table) ([]*model.Constraint, []*model.ForeignKey, error)
func (*Catalog) ListDomains ¶ added in v0.12.0
func (*Catalog) ListIndexes ¶
func (*Catalog) ListPoliciesByTable ¶ added in v1.3.0
func (c *Catalog) ListPoliciesByTable(ctx context.Context, table *model.Table) ([]*model.Policy, error)
ListPoliciesByTable returns row-level security policies attached to the given table, in pg_policy.polname order.
func (*Catalog) ListSequences ¶ added in v1.17.0
ListSequences returns all sequences in the filtered schemas, including those owned by serial/identity columns. OwnerTable/OwnerColumn identify the owning column (nil for standalone sequences).
func (*Catalog) ListTables ¶
func (*Catalog) Sequences ¶
Sequences returns the standalone sequences in the filtered schemas, keyed by FQN. Sequences owned by a table column (serial or identity) are excluded: they are managed as column attributes, not as standalone objects.
Click to show internal directories.
Click to hide internal directories.